@@ -34,6 +34,7 @@ setGeneric(name="inputs<-",def=function(.Object, ..., value){
 #'@param ... arguments matching fields in .Object's processInputs slot
 #'@rdname inputs-webprocess
 #'@aliases inputs
+#'@importFrom XML getNodeSet xmlToList
 #'@export
 #'@keywords internal
 setGeneric(name="inputs",def=function(.Object, ..., value){standardGeneric("inputs")})
@@ -50,6 +51,27 @@ setMethod(f = "inputs",signature = "webprocess",
             }
           })
 
+#'@rdname inputs-webprocess
+#'@aliases inputs
+setMethod(f = "inputs",signature = "XMLAbstractDocument",
+          definition = function(.Object, ...){
+            inputXpath <- "//wps:Execute/wps:DataInputs/wps:Input"
+            
+            inputs <- getNodeSet(.Object, inputXpath, namespaces = pkg.env$NAMESPACES)
+            results <- list()
+            names <- c()
+            for (i in 1:length(inputs)) {
+              xmlList <- xmlToList(inputs[[i]], addAttributes = FALSE)
+              # only extract literal data
+              if (!is.null(xmlList$Data) && !is.null(xmlList$Data$LiteralData)) {
+                results <- c(results, xmlList$Data$LiteralData)
+                names <- c(names, xmlList$Identifier)
+              }
+            }
+            names(results) <- names
+            
+            return(results)
+          })
 
 #'@rdname inputs-webprocess
 #'@aliases inputs<-
